package de.uniulm.mathematik.typo.hyphen;

import java.io.*;
import java.lang.*;
import de.uniulm.mathematik.tries.*;

/**
 * This class provides two static methods that allow to load
 * a hyphenation table from a file. This file is expected to
 * consist of hyphenation patterns only, one per line.
 * <P/>
 * Please note that the <I>hyphen.tex</I> file of the TeX
 * distribution cannot be taken directly as input as the
 * current implementation does not attempt to parse the TeX
 * constructs in these hyphenation files. Instead, the
 * part between <code>patterns{</code> and the closing bracket
 * has to be copied to another file with one rule per line.
 * Comments have to be stripped as well.
 * @see HyphenationTableConstructor
 */
public class HyphenationTableLoader {
   /**
    * Load a hyphenation table from the given filename.
    * @param filename path of the file to be opened
    */
   public static TrieReader<HyphenationEntry> open(String filename)
	 throws FileNotFoundException, IOException {
      return open(new BufferedReader(new FileReader(filename)));
   }

   /**
    * Load a hyphenation table from the given buffered reader.
    * @param in buffered reader from which the hyphenation table is read
    */
   public static TrieReader<HyphenationEntry> open(BufferedReader in)
	 throws IOException {
      HyphenationTableConstructor htc = new HyphenationTableConstructor();
      int ch;
      StringBuffer line = new StringBuffer();
      while ((ch = in.read()) >= 0) {
	 if (ch == '\n') {
	    htc.add(line.toString());
	    line.setLength(0);
	 } else {
	    line.appendCodePoint(ch);
	 }
      }
      return htc.finish();
   }
}
