package de.uniulm.mathematik.typo.items;

import de.uniulm.mathematik.typo.fonts.*;

/**
 * This class delegates all operations to another item. It serves
 * as common base of various wrapper classes.
 */
public class DelegatingItem implements Item {
   /**
    * The item to which all operations are delegated to unless overridden.
    */
   protected Item item;

   /**
    * Construct a delegating item for the given item.
    */
   public DelegatingItem(Item item) {
      assert(item != null);
      this.item = item;
   }

   /**
    * Delegate this method to the wrapped item.
    */
   public boolean isPenalty() {
      return item.isPenalty();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public boolean isGlue() {
      return item.isGlue();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public boolean isBox() {
      return item.isBox();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public int getWidth() {
      return item.getWidth();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public int getStretchability() {
      return item.getStretchability();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public int getShrinkability() {
      return item.getShrinkability();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public void shrink(int units) {
      item.shrink(units);
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public void stretch(int units) {
      item.stretch(units);
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public int getHeight() {
      return item.getHeight();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public int getDepth() {
      return item.getDepth();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public int getChar() {
      return item.getChar();
   }
   /**
    * If this box represents a printable char, return its font,
    * otherwise null.
    */
   public FontMetrics getFont() {
      return item.getFont();
   }
   /**
    * If this box represents a printable char, return its font size,
    * otherwise 0.
    */
   public int getFontSize() {
      return item.getFontSize();
   }
   /**
    * Returns false.
    */
   public boolean isKerning() {
      return item.isKerning();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public int getPenalty() {
      return item.getPenalty();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public boolean getPenaltyFlag() {
      return item.getPenaltyFlag();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public Item getHyphen() {
      return item.getHyphen();
   }
   /**
    * Delegate this method to the wrapped item.
    */
   public StringBuffer genPostScript(PostScriptContext context) {
      return item.genPostScript(context);
   }
} // class DelegatingItem
