package de.uniulm.mathematik.typo.items;

import java.util.*;

/**
 * Unfortunately iterators are not iterable in Java. Hence we
 * need a class that wraps an iterator in an iterable object.
 * This code is based on an idea by Sebastian Rittau, see his
 * <A HREF="http://www.rittau.org/blog/20061122-00">blog entry</A>.
 */
public class IterableIterator<T> implements Iterable<T>, Iterator<T> {
   private Iterator<T> iter;

   /**
    * Construct an iterable iterator out of a non-iterable iterator.
    */
   public IterableIterator(Iterator<T> iter) {
      this.iter = iter;
   }

   /**
    * Implementation of the Iterable interface.
    */
   public Iterator<T> iterator() {
      return iter;
   }

   /**
    * Implementation the hasNext() method of the Iterator interface:
    * The method invocation is delegated to the wrapped iterator.
    */
   public boolean hasNext() {
      return iter.hasNext();
   }

   /**
    * Implementation the next() method of the Iterator interface:
    * The method invocation is delegated to the wrapped iterator.
    */
   public T next() {
      return iter.next();
   }

   /**
    * Implementation the remove() method of the Iterator interface:
    * The method invocation is delegated to the wrapped iterator.
    */
   public void remove() {
      iter.remove();
   }
} // class IterableIterator
