package de.uniulm.mathematik.typo.items;

/**
 * General interface for line-breaking algorithms which convert
 * a horizontal sequence into a vertical box consisting of individual
 * lines.
 */
public interface LineBreaker {
   /**
    * Process each line by this wrapper before adding it
    * to the vertical box.
    */
   public void setLineWrapper(SequenceWrapper wrapper);

   /**
    * Process the horizontal box immediately before it
    * gets added to the vertical box.
    */
   public void setHorizontalBoxWrapper(ItemWrapper hboxwrapper);

   /**
    * Break the horizontal sequence into individual lines that are
    * stacked up in a newly created vertical box that is returned.
    * @param hseq the horizontal sequence which is to be broken into
    *             lines. Note that the algorithm is free to adapt
    *             the widths of individual items of that sequence.
    * @param parwidth the width of the paragraph in units (1/1000 points).
    * @param baselineskip the vertical distance between the baselines
    *             of two subsequent lines in units (1/1000 points).
    */
   public Item breakParagraph(HorizontalSequence hseq,
      int parwidth, int baselineskip);
} // interface LineBreaker
