package de.uniulm.mathematik.typo.items;

import java.util.*;

public class LineBreakerFactory {
   public interface Constructor {
      LineBreaker create();
   } // interface Constructor

   private TreeMap<String, Constructor> constructors;

   public LineBreakerFactory() {
      constructors = new TreeMap<String, Constructor>();
   }
   
   public void add(String key, Constructor constructor) {
      assert(key != null && constructor != null);
      assert(!constructors.containsKey(key));
      constructors.put(key, constructor);
   }

   public LineBreaker create(String key) {
      Constructor constructor = constructors.get(key);
      if (constructor == null) {
	 return null;
      } else {
	 return constructor.create();
      }
   }

   public String getAlternatives() {
      StringBuffer buffer = null;
      for (String key: constructors.keySet()) {
	 if (buffer == null) {
	    buffer = new StringBuffer(key);
	 } else {
	    buffer.append("|");
	    buffer.append(key);
	 }
      }
      if (buffer == null) {
	 return "";
      } else {
	 return buffer.toString();
      }
   }
} // class LineBreakerFactory
