package de.uniulm.mathematik.tries;

/**
 * Reading interface for tries.
 */
public interface TrieReader<TrieInfo> {

   /**
    * Trie pointers represent pointer to trie nodes
    * that allow to navigate downward through a trie.
    */
   public interface TriePointer<TrieInfo> {
      /**
       * Move downward to the sub-trie associated with code.
       * @param code The next codepoint of the key.
       * @return pointer to node representing the sub-trie,
       *         null is returned if no such sub-trie exists
       */
      public TriePointer<TrieInfo> descend(int code);

      /**
       * Returns TrieInfo object associated with this node.
       * Null is returned if no object is associated with it.
       */
      public TrieInfo getInfo();
   }

   /**
    * Return root node of this trie which is always non-null.
    */
   public TriePointer<TrieInfo> getRoot();

   /**
    * Return number of info objects stored into this trie.
    */
   public int getNumberOfEntries();

   /**
    * Return number of nodes within this trie.
    */
   public int getNumberOfNodes();
}
